AtLocationFlutterPlugin class

A class defined to show markers based on current location of mentioned atsigns.

Inheritance

Constructors

AtLocationFlutterPlugin(List<String?>? atsignsToTrack, {Key? key, double? left, double? right, double? top, double? bottom, bool calculateETA = false, bool addCurrentUserMarker = false, String? textForCenter = 'Centre', LatLng? etaFrom, String? focusMapOn, String? notificationID, DateTime? refreshAt})

Properties

addCurrentUserMarker ↔ bool
calculateETA if ETA needs to be calculated/displayed. addCurrentUserMarker if logged in users current location should be added to the map.
getter/setter pair
atsignsToTrack → List<String?>?
Atsigns whose location needs to be shown.
final
bottom ↔ double?
Padding for the markers.
getter/setter pair
calculateETA ↔ bool
calculateETA if ETA needs to be calculated/displayed. addCurrentUserMarker if logged in users current location should be added to the map.
getter/setter pair
etaFrom ↔ LatLng?
ETA will be calculated from this co-ordinate.
getter/setter pair
focusMapOn ↔ String?
textForCenter Text for the co-ordinate from where ETA is calculated.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
left ↔ double?
Padding for the markers.
getter/setter pair
notificationID ↔ String?
needed to track details of a specific notification (event/p2p).
getter/setter pair
refreshAt ↔ DateTime?
needed if we want to check for location data after a particular time
getter/setter pair
Padding for the markers.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textForCenter ↔ String?
textForCenter Text for the co-ordinate from where ETA is calculated.
getter/setter pair
top ↔ double?
Padding for the markers.
getter/setter pair

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _AtLocationFlutterPluginState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited