FitBoundsOptions class

Constructors

FitBoundsOptions({EdgeInsets padding = const EdgeInsets.all(0.0), double maxZoom = 17.0, double? zoom})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
maxZoom → double
final
padding → EdgeInsets
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
zoom → double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited