LocationDataModel class

Constructors

LocationDataModel(Map<String, LocationSharingFor> locationSharingFor, double? lat, double? long, DateTime lastUpdatedAt, String sender, String receiver)
Enhancement: add a bool for retry
LocationDataModel.fromJson(Map<String, dynamic> data)

Properties

getLatLng → LatLng?
no setter
hashCode → int
The hash code for this object.
no setterinherited
lastUpdatedAt ↔ DateTime
getter/setter pair
lat ↔ double?
getter/setter pair
locationSharingFor ↔ Map<String, LocationSharingFor>
locationSharingFor accepts id as key and LocationSharingFor as data.
getter/setter pair
long ↔ double?
getter/setter pair
receiver ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sender ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited