LocationModal class

Constructors

LocationModal({String? lat, String? long, String? displayName, String? state, String? city, String? postalCode})
LocationModal.fromJson(Map ad)

Properties

city ↔ String?
getter/setter pair
displayName ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lat ↔ String?
getter/setter pair
long ↔ String?
getter/setter pair
postalCode ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited