Crs class abstract

An abstract representation of a Coordinate Reference System.

The main objective of a CRS is to handle the conversion between surface points of objects of different dimensions. In our case 3D and 2D objects.

Implementers

Constructors

Crs()
const

Properties

code → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
infinite → bool
no setter
projection → Projection
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transformation → Transformation
no setter
wrapLat → Tuple2<double, double>?
no setter
wrapLng → Tuple2<double, double>?
no setter

Methods

getProjectedBounds(double zoom) → Bounds<num>?
Rescales the bounds to a given zoom value.
latLngToPoint(LatLng? latlng, double zoom) → CustomPoint<num>
Converts a point on the sphere surface (with a certain zoom) in a map point.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pointToLatLng(CustomPoint<num> point, double zoom) → LatLng?
Converts a map point to the sphere coordinate (at a certain zoom).
scale(double zoom) → num?
Zoom to Scale function.
toString() → String
A string representation of this object.
inherited
zoom(double scale) → num
Scale to Zoom function.

Operators

operator ==(Object other) → bool
The equality operator.
inherited