Projection class abstract

Implementers

Constructors

Projection()
const

Properties

bounds → Bounds<double>?
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

inclusiveLat(double value) → double
inclusiveLng(double value) → double
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
project(LatLng? latlng) → CustomPoint<num>
toString() → String
A string representation of this object.
inherited
unproject(CustomPoint<num> point) → LatLng

Operators

operator ==(Object other) → bool
The equality operator.
inherited