CircleLayerOptions class

Inheritance

Constructors

CircleLayerOptions({Key? key, List<CircleMarker> circles = const [], dynamic rebuild})

Properties

circles → List<CircleMarker>
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
finalinherited
rebuild → Stream<Null>?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited