Polyline class

Constructors

Polyline({List<LatLng>? points, double strokeWidth = 1.0, Color color = const Color(0xFF00FF00), double borderStrokeWidth = 0.0, Color borderColor = const Color(0xFFFFFF00), List<Color>? gradientColors, List<double>? colorsStop, bool isDotted = false})

Properties

borderColor → Color
final
borderStrokeWidth → double
final
boundingBox ↔ LatLngBounds
getter/setter pair
color → Color
final
colorsStop → List<double>?
final
gradientColors → List<Color>?
final
hashCode → int
The hash code for this object.
no setterinherited
isDotted → bool
final
offsets → List<Offset>
final
points → List<LatLng>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
strokeWidth → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited