PolylineLayerOptions class

Inheritance

Constructors

PolylineLayerOptions({Key? key, List<Polyline> polylines = const [], bool polylineCulling = false, dynamic rebuild})

Properties

hashCode → int
The hash code for this object.
no setterinherited
key → Key?
finalinherited
polylineCulling → bool
final
polylines → List<Polyline>
final
rebuild → Stream<Null>?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited