KeyStreamService class

Constructors

KeyStreamService()
factory

Properties

allLocationNotifications ↔ List<KeyLocationModel>
getter/setter pair
atClientInstance ↔ AtClient?
getter/setter pair
atContactImpl ↔ AtContactsImpl?
getter/setter pair
atNotificationsController ↔ StreamController
getter/setter pair
atNotificationsSink → StreamSink<List<KeyLocationModel>>
no setter
atNotificationsStream → Stream<List<KeyLocationModel>>
no setter
contactList ↔ List<AtContact>
getter/setter pair
currentAtSign ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
loggedInUserDetails ↔ AtContact?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
streamAlternative ↔ dynamic Function(List<KeyLocationModel>)?
getter/setter pair

Methods

addDataToList(LocationNotificationModel locationNotificationModel, {String? receivedkey}) → Future
Adds new KeyLocationModel data for new received notification
checkForDeleteRequestAck() → void
Checks for missed 'Remove Person' requests for request location notifications
checkForPendingLocations() → Future<void>
Updates any received notification with haveResponded true, if already responded.
deleteData(LocationNotificationModel locationNotificationModel) → dynamic
Deletes data associated with a LocationNotificationModel
filterData() → void
Removes past notifications and notification where data is null.
getAllContactDetails(String currentAtSign) → void
getAllNotifications() → void
adds all share and request location notifications to atNotificationsSink
getAtValue(AtKey key) → Future
Retrieves the value of an AtKey
init(AtClient? clientInstance, {dynamic streamAlternative(List<KeyLocationModel>)?}) → void
isPastNotification(LocationNotificationModel _locationNotificationModel) → dynamic
Checks if a location notification is in the past
mapUpdatedLocationDataToWidget(LocationNotificationModel locationData, {bool shouldCheckForTimeChanges = false}) → Future<void>
Updates any KeyLocationModel data for updated data
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Returns updated list
removeData(String? key) → void
Removes a notification from list
toString() → String
A string representation of this object.
inherited
updatePendingStatus(LocationNotificationModel notification) → void
Updates the pending status of a location notification

Operators

operator ==(Object other) → bool
The equality operator.
inherited