RequestLocationService class

Constructors

RequestLocationService()
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkForAlreadyExisting(String? atsign) → List
checks if logged in user has already requested location from atsign.
checkForAlreadyExistingShareLocation(String? atsign) → List
checks if atsign is already sharing location with logged in user.
checkIfEventIsNotResponded(LocationNotificationModel locationNotificationModel) → bool
checks if logged in user's already requested location with atsign is not responded.
checkIfEventIsRejected(LocationNotificationModel locationNotificationModel) → bool
checks if logged in user's already requested location with atsign is rejected.
deleteKey(LocationNotificationModel locationNotificationModel) → Future<bool>
Deletes originally created locationNotificationModel notification
newAtKey(int ttr, String key, String? sharedWith, {int? ttl, DateTime? expiresAt}) → AtKey
returns a new AtKey.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requestLocationAcknowledgment(LocationNotificationModel originalLocationNotificationModel, bool isAccepted, {bool sendAck = false, int? minutes, bool? isSharing}) → Future<bool>
Sends a 'requestlocationacknowledged' key to originalLocationNotificationModel.receiver with isAccepted as isAccepted and duration of minutes minute
sendDeleteAck(LocationNotificationModel locationNotificationModel) → Future<bool>
Sends a 'deleterequestacklocation' key to delete the originally created key
sendRequestLocationEvent(String? atsign) → Future<bool?>
Sends a 'requestlocation' key to atsign.
sendRequestLocationToGroup(List<AtContact> selectedContacts) → Future<void>
Sends request location to selectedContacts.
toString() → String
A string representation of this object.
inherited
updateWithRequestLocationAcknowledge(LocationNotificationModel originalLocationNotificationModel, {bool rePrompt = false}) → Future
Updates originally created locationNotificationModel with originalLocationNotificationModel data If rePrompt is true, then will show dialog box on receiver's side.

Operators

operator ==(Object other) → bool
The equality operator.
inherited